@@ -2,7 +2,6 @@
 
 using namespace Rcpp;
 
-// [[Rcpp::export]]
 double haversine_cpp(double lat1, double long1,
                      double lat2, double long2,
                      double earth_radius = 6378137){
@@ -19,6 +18,33 @@ double haversine_cpp(double lat1, double long1,
 }
 
 
+// [[Rcpp::export]]
+Rcpp::NumericVector haversine_cpp_vec(Rcpp::NumericVector latFrom, Rcpp::NumericVector lonFrom,
+                                            Rcpp::NumericVector latTo, Rcpp::NumericVector lonTo,
+                                            double earth_radius) {
+  int n = latFrom.size();
+  Rcpp::NumericVector distance(n);
+
+  double latf;
+  double latt;
+  double lonf;
+  double lont;
+  double dist = 0;
+
+  for(int i = 0; i < n; i++){
+
+    latf = latFrom[i];
+    lonf = lonFrom[i];
+    latt = latTo[i];
+    lont = lonTo[i];
+    dist = haversine_cpp(latf, lonf, latt, lont, earth_radius);
+
+    distance[i] = dist;
+  }
+  return distance;
+}
+
+
 // [[Rcpp::export]]
 DataFrame haversine_loop_cpp(DataFrame x, double lat_center, double lon_center, double radius = 200) {
 
